# Photon Weave
![Coverage](assets/coverage.svg)

Photon Weave is a quantum optics simulator designd for modeling and analysis of quantum systems. Focusing on individual temporal modes, it offers comprehensive support for simulating quantums tates within Fock spaces  along with their polarization degrees of freedom.

## Instalation

This package can be installed using pip:
```bash
pip install photon-weave
```
or it can be installed from this repository:
```bash
pip install git+https://github.com/tqsd/photon_weave.git
```

### Instalation for developing
In case you want to add a feature, you can install the system with
```bash
git clone git@github.com:tqsd/photon_weave.git
cd photon_weave
pip install -e .
```
